@@ -1431,7 +1431,7 @@ cell_pct <- function(txt, align = "left", width = NULL) {
 
 #' Bottom border means it is a header row
 #' @noRd
-cell_abs <- function(txt, align = "left", width = NULL, borders = NULL, valign = NULL) {
+cell_abs <- function(txt, align = "left", width = NULL, borders = NULL, valign = NULL, bold = FALSE) {
   
   al <- ""
   bb <- ""
@@ -1451,6 +1451,7 @@ cell_abs <- function(txt, align = "left", width = NULL, borders = NULL, valign =
     }
   }
   
+  
   if (is.null(width)) {
     ret <- paste0('<w:tc><w:tcPr>', bb, al, '</w:tcPr>', 
                   para(txt, align),
@@ -1458,7 +1459,7 @@ cell_abs <- function(txt, align = "left", width = NULL, borders = NULL, valign =
     
   } else {
     ret <- paste0('<w:tc><w:tcPr><w:tcW w:w="', width,'"/>', bb, al, '</w:tcPr>', 
-                  para(txt, align),
+                  para(txt, align, bold = bold),
                   "</w:tc>\n", collapse = "")
   }
   
@@ -1521,7 +1522,7 @@ run <- function(txt) {
 }
 
 #' @noRd
-get_cell_borders_docx <- function(row, col, trow, tcol, brdrs) {
+get_cell_borders_docx <- function(row, col, trow, tcol, brdrs, flg = NULL) {
   
   ret <- ""
   r <- ""
@@ -1547,6 +1548,14 @@ get_cell_borders_docx <- function(row, col, trow, tcol, brdrs) {
       r <- '<w:right w:val="single" w:sz="4" w:space="0" w:color="auto"/>'
     }
     
+    if (!is.null(flg)) {
+      if (flg %in% c("L", "B")) {
+        if (col == 1 & any(brdrs %in% c("right", "body"))) {
+          r <- '<w:right w:val="single" w:sz="4" w:space="0" w:color="auto"/>'
+        }
+      }
+    }
+    
     if (b != "" | l != "" | r != "" | t!= "") {
               
       ret <-  paste0('<w:tcBorders>', r, l, t, b,
